JsErrorExtension

Trait JsErrorExtension 

pub trait JsErrorExtension {
    // Required method
    fn message(&self) -> String;
}
Extension trait that exposes the message property of a JsError.

Required Methods

fn message(&self) -> String

Returns the message property of the error as a string.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl JsErrorExtension for JsError

Source

fn message(&self) -> String

Implementors