JsValueErrorTrait

Trait JsValueErrorTrait 

pub trait JsValueErrorTrait {
    // Required method
    fn message(&self) -> String;
}
Extension trait for reading the message property from a JsValue that represents a JavaScript error.

Required Methods

fn message(&self) -> String

Returns the message property of the error value as a string.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl JsValueErrorTrait for JsValue

Source

fn message(&self) -> String

Implementors