Workflow RS framework initializers
Functions
- global
- Returns the
$workflow$global object holding the registered workflow and modules. - init_
workflow - Initializes the workflow framework by registering the supplied
workflowandmodulesobjects under the$workflow$JavaScript global and enabling log colors. - modules
- Returns the registered application modules object stored in the workflow global.
- workflow
- Returns the registered workflow object stored in the workflow global.